/*=========================================================================

Library:   TubeTK

Copyright 2010 Kitware Inc. 28 Corporate Drive,
Clifton Park, NY, 12065, USA.

All rights reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

=========================================================================*/
#ifndef __itkDoubleArrayValue_h
#define __itkDoubleArrayValue_h

#include "itkParameterValue.h"

namespace itk
{

/**
 * \class DoubleArrayValue
 *
 * \brief Holds the value of a DOUBLE_ARRAY ParameterValueType.
 *
 * \sa ParameterValue
 * */
class DoubleArrayValue: public ParameterValue
{
public:
  typedef std::vector< double > DoubleArrayType;

  DoubleArrayValue()
    {
    this->m_ValueType = DOUBLE_ARRAY;
    }

  const DoubleArrayType & GetValue() const
    {
    return m_DoubleArray;
    }

  DoubleArrayType & GetModifiableValue()
    {
    return m_DoubleArray;
    }

  void SetValue( const DoubleArrayType & value )
    {
    m_DoubleArray = value;
    }

private:
  DoubleArrayType m_DoubleArray;
};

} // end namespace itk

#endif
