/*=========================================================================

Library:   TubeTK

Copyright 2010 Kitware Inc. 28 Corporate Drive,
Clifton Park, NY, 12065, USA.

All rights reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

=========================================================================*/
#ifndef __itkFloatArrayValue_h
#define __itkFloatArrayValue_h

#include "itkParameterValue.h"

namespace itk
{

/**
 * \class FloatArrayValue
 *
 * \brief Holds the value of a FLOAT_ARRAY ParameterValueType.
 *
 * \sa ParameterValue
 * */
class FloatArrayValue: public ParameterValue
{
public:
  typedef std::vector< float > FloatArrayType;

  FloatArrayValue()
    {
    this->m_ValueType = FLOAT_ARRAY;
    }

  const FloatArrayType & GetValue() const
    {
    return m_FloatArray;
    }

  FloatArrayType & GetModifiableValue()
    {
    return m_FloatArray;
    }

  void SetValue( const FloatArrayType & value )
    {
    m_FloatArray = value;
    }

private:
  FloatArrayType m_FloatArray;
};

} // end namespace itk

#endif
